==> owncloud-9.0.3.tgz: owncloud/apps/files_sharing/l10n/is.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Deiling frá þjóni til þjóns er ekki virk á þessum þjóni",
    "The mountpoint name contains invalid characters." : "Heiti tengipunktsins inniheldur ógilda stafi.",
    "Not allowed to create a federated share with the same user server" : "Ekki er heimilt að búa til skýjasambandssameign með sama notendaþjóni",
    "Invalid or untrusted SSL certificate" : "Ógilt eða vantreyst SSL-skilríki",
    "Could not authenticate to remote share, password might be wrong" : "Gat ekki auðkennt á fjartengdri sameign, lykilorð gæti verið rangt",
    "Storage not valid" : "Geymslan er ekki gild",
    "Couldn't add remote share" : "Gat ekki bætt við fjartengdri sameign",
    "Shared with you" : "Deilt með þér",
    "Shared with others" : "Deilt með öðrum",
    "Shared by link" : "Deilt með tengli",
    "Federated sharing" : "Deiling milli þjóna",
    "Nothing shared with you yet" : "Engu deilt með þér ennþá",
    "Files and folders others share with you will show up here" : "Skrár og möppur sem aðrir deila með þér birtast hér",
    "Nothing shared yet" : "Engu deilt ennþá",
    "Files and folders you share will show up here" : "Skrár og möppur sem þú deilir birtast hér",
    "No shared links" : "Engir sameignartenglar",
    "Files and folders you share by link will show up here" : "Skrár og möppur sem þú deilir með tenglum birtast hér",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Viltu bæta við fjartengdri sameign {name} frá {owner}@{remote}?",
    "Remote share" : "Fjartengd sameign",
    "Remote share password" : "Lykilorð fjartengdrar sameignar",
    "Cancel" : "Hætta við",
    "Add remote share" : "Bæta við fjartengdri sameign",
    "You can upload into this folder" : "Þú getur sent inn skrár í þessa möppu",
    "No ownCloud installation (7 or higher) found at {remote}" : "Engin ownCloud uppsetning (útgáfa 7 eða nýrri) fannst á {remote}",
    "Invalid ownCloud url" : "Ógild ownCloud-slóð",
    "Shared by" : "Deilt af",
    "Sharing" : "Deiling",
    "A file or folder has been <strong>shared</strong>" : "Skjali eð  möppu hefur verið <strong>deilt</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Skjali eð  möppu hefur verið deilt <strong>frá öðrum þjóni</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Skrá eða mappa í almenningsaðgangi var <strong>sótt</strong>",
    "You received a new remote share %2$s from %1$s" : "Þú tókst við nýrri fjartengdri sameign %2$s frá %1$s",
    "You received a new remote share from %s" : "Þú tókst við nýrri fjartengdri sameign frá %s",
    "%1$s accepted remote share %2$s" : "%1$s samþykkti fjartengda sameign %2$s",
    "%1$s declined remote share %2$s" : "%1$s hafnaði fjartengdri sameign %2$s",
    "%1$s unshared %2$s from you" : "%1$s tók af deilingu %2$s frá þér",
    "Public shared folder %1$s was downloaded" : "Deild mappa í almenningsaðgangi %1$s var sótt",
    "Public shared file %1$s was downloaded" : "Deild skrá í almenningsaðgangi %1$s var sótt",
    "You shared %1$s with %2$s" : "Þú deildir %1$s með %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s deildi %1$s með %3$s",
    "You removed the share of %2$s for %1$s" : "Þú fjarlægðir deilingu af %2$s fyrir %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s fjarlægði deilingu af %3$s fyrir %1$s",
    "You shared %1$s with group %2$s" : "Þú deildir %1$s með hópnum %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s deildi %1$s með hópnum %3$s",
    "You removed the share of group %2$s for %1$s" : "Þú fjarlægðir deilingu til hópsins %2$s fyrir %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s fjarlægði deilingu til hópsins %3$s fyrir %1$s",
    "%2$s shared %1$s via link" : "%2$s deildi %1$s með tengli",
    "You shared %1$s via link" : "Þú deildir %1$s með tengli",
    "You removed the public link for %1$s" : "Þú fjarlægðir almenningstengilinn fyrir %1$s",
    "%2$s removed the public link for %1$s" : "%2$s fjarlægði almenningstengilinn fyrir %1$s",
    "Your public link for %1$s expired" : "Almenningstengill þinn fyrir %1$s er útrunninn",
    "The public link of %2$s for %1$s expired" : "Almenningstengill %2$s fyrir %1$s er útrunninn",
    "%2$s shared %1$s with you" : "%2$s deildi %1$s með þér",
    "%2$s removed the share for %1$s" : "%2$s fjarlægði deilingu af %1$s",
    "Downloaded via public link" : "Náð í með almenningstengli",
    "Shared with %2$s" : "Deilt með %2$s",
    "Shared with %3$s by %2$s" : "Deilt með %3$s af %2$s",
    "Removed share for %2$s" : "Fjarlægði deilingu af %2$s",
    "%2$s removed share for %3$s" : "%2$s fjarlægði deilingu af %3$s",
    "Shared with group %2$s" : "Deilt með hópnum %2$s",
    "Shared with group %3$s by %2$s" : "Deilt með hópnum %3$s af %2$s",
    "Removed share of group %2$s" : "Fjarlægði deilingu af hópnum %2$s",
    "%2$s removed share of group %3$s" : "%2$s fjarlægði deilingu af hópnum %3$s",
    "Shared via link by %2$s" : "Deilt með tengli af %2$s",
    "Shared via public link" : "Deilt með almenningstengli",
    "Removed public link" : "Fjarlægði almenningstengil",
    "%2$s removed public link" : "%2$s fjarlægði almenningstengil",
    "Public link expired" : "Almenningstengill er útrunninn",
    "Public link of %2$s expired" : "Almenningstengill %2$s er útrunninn",
    "Shared by %2$s" : "Deilt af %2$s",
    "Shares" : "Sameignir",
    "You received \"/%2$s\" as a remote share from %1$s" : "Þú tókst við \"/%2$s\" sem fjartengdri sameign frá %1$s",
    "Accept" : "Samþykkja",
    "Decline" : "Hafna",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Deila með mér í gegnum víðværa skýjasambandsauðkennið mitt #ownCloud Federated Cloud ID, sjá %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Deila með mér í gegnum víðværa skýjasambandsauðkennið mitt #ownCloud Federated Cloud ID",
    "This share is password-protected" : "Þessi sameign er varin með lykilorði",
    "The password is wrong. Try again." : "Lykilorðið er rangt. Reyndu aftur.",
    "Password" : "Lykilorð",
    "No entries found in this folder" : "Engar skrár fundust í þessari möppu",
    "Name" : "Nafn",
    "Share time" : "Deilingartími",
    "Sorry, this link doesn’t seem to work anymore." : "Því miður, þessi tengill virðist ekki virka lengur.",
    "Reasons might be:" : "Mögulegar ástæður gætu verið:",
    "the item was removed" : "atriðið var fjarlægt",
    "the link expired" : "tengillinn er útrunninn",
    "sharing is disabled" : "slökkt er á skráadeilingu",
    "For more info, please ask the person who sent this link." : "Til að vita meira skaltu hafa samband við þann sem sendi þér þennan tengil.",
    "Add to your ownCloud" : "Bæta í þitt eigið ownCloud",
    "Download" : "Niðurhal",
    "Download %s" : "Sækja %s",
    "Direct link" : "Beinn tengill",
    "Federated Cloud Sharing" : "Deiling með skýjasambandi",
    "Open documentation" : "Opna hjálparskjöl",
    "Allow users on this server to send shares to other servers" : "Leyfa notendum á þessum þjóni að senda sameignir til annarra þjóna",
    "Allow users on this server to receive shares from other servers" : "Leyfa notendum á þessum þjóni að taka á móti sameignum frá öðrum þjónum",
    "Federated Cloud" : "Skýjasamband (federated)",
    "Your Federated Cloud ID:" : "Skýjasambandsauðkennið þitt (Federated Cloud ID):",
    "Share it:" : "Deila því:",
    "Add to your website" : "Bæta við vefsvæðið þitt",
    "Share with me via ownCloud" : "Deila með mér í gegnum ownCloud",
    "HTML Code:" : "HTML-kóði:",
    "Public link of %2$s expired" : "Almenningstengill %2$s er útrunninn",
    "Public shared file %1$s was downloaded" : "Deild skrá í almenningsaðgangi %1$s var sótt",
    "Public shared folder %1$s was downloaded" : "Deild mappa í almenningsaðgangi %1$s var sótt",
    "Removed share for %2$s" : "Fjarlægði deilingu af %2$s",
    "Removed share of group %2$s" : "Fjarlægði deilingu af hópnum %2$s",
    "Shared by %2$s" : "Deilt af %2$s",
    "Shared via link by %2$s" : "Deilt með tengli af %2$s",
    "Shared with group %3$s by %2$s" : "Deilt með hópnum %3$s af %2$s",
    "The public link of %2$s for %1$s expired" : "Almenningstengill %2$s fyrir %1$s er útrunninn",
    "You removed the public link for %1$s" : "Þú fjarlægðir almenningstengilinn fyrir %1$s",
    "You removed the share of %2$s for %1$s" : "Þú fjarlægðir deilingu af %2$s fyrir %1$s",
    "You removed the share of group %2$s for %1$s" : "Þú fjarlægðir deilingu til hópsins %2$s fyrir %1$s",
    "Your public link for %1$s expired" : "Almenningstengill þinn fyrir %1$s er útrunninn"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> owncloud-10.0.7.tgz: owncloud/apps/files_sharing/l10n/is.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Deiling frá þjóni til þjóns er ekki virk á þessum þjóni",
    "The mountpoint name contains invalid characters." : "Heiti tengipunktsins inniheldur ógilda stafi.",
    "Not allowed to create a federated share with the same user server" : "Ekki er heimilt að búa til skýjasambandssameign með sama notendaþjóni",
    "Invalid or untrusted SSL certificate" : "Ógilt eða vantreyst SSL-skilríki",
    "Could not authenticate to remote share, password might be wrong" : "Gat ekki auðkennt á fjartengdri sameign, lykilorð gæti verið rangt",
    "Storage not valid" : "Gagnageymslan er ekki gild",
    "Couldn't add remote share" : "Gat ekki bætt við fjartengdri sameign",
    "Shared with you" : "Deilt með þér",
    "Shared with others" : "Deilt með öðrum",
    "Shared by link" : "Deilt með tengli",
    "Anonymous upload" : "Nafnlaus innsending",
    "Click to select files or use drag & drop to upload" : "Smelltu til að velja skrár eða notaðu draga/sleppa til innsendingar",
    "Uploaded files" : "Innsendar skrár",
    "Uploading..." : "Sendi inn ...",
    "Nothing shared with you yet" : "Engu deilt með þér ennþá",
    "Files and folders others share with you will show up here" : "Skrár og möppur sem aðrir deila með þér birtast hér",
    "Nothing shared yet" : "Engu deilt ennþá",
    "Files and folders you share will show up here" : "Skrár og möppur sem þú deilir birtast hér",
    "No shared links" : "Engir sameignartenglar",
    "Files and folders you share by link will show up here" : "Skrár og möppur sem þú deilir með tenglum birtast hér",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Viltu bæta við fjartengdri sameign {name} frá {owner}@{remote}?",
    "Remote share" : "Fjartengd sameign",
    "Remote share password" : "Lykilorð fjartengdrar sameignar",
    "Cancel" : "Hætta við",
    "Add remote share" : "Bæta við fjartengdri sameign",
    "You can upload into this folder" : "Þú getur sent inn skrár í þessa möppu",
    "No ownCloud installation (7 or higher) found at {remote}" : "Engin ownCloud uppsetning (útgáfa 7 eða nýrri) fannst á {remote}",
    "Invalid ownCloud url" : "Ógild ownCloud-slóð",
    "Share" : "Deila",
    "No expiration date set" : "Engin dagsetning fyrir gildistíma er sett",
    "Shared by" : "Deilt af",
    "Sharing" : "Deiling",
    "Share API is disabled" : "Deilingar-API er óvirkt",
    "Wrong share ID, share doesn't exist" : "Rangt auðkenni sameignar, sameign er ekki til",
    "Could not delete share" : "Tókst ekki að eyða sameign",
    "Please specify a file or folder path" : "Tiltaktu skrá eða slóð á möppu",
    "Wrong path, file/folder doesn't exist" : "Röng slóð, skrá/mappa er ekki til",
    "Cannot remove all permissions" : "Get ekki fjarlægt allar aðgangsheimildir",
    "Please specify a valid user" : "Settu inn gilt notandanafn",
    "Group sharing is disabled by the administrator" : "Deiling innan hóps hefur verið gerð óvirk af kerfisstjóra.",
    "Please specify a valid group" : "Settu inn gildan hóp",
    "Public link sharing is disabled by the administrator" : "Deiling opinberra sameignartengla hefur verið gerð óvirk af kerfisstjóra.",
    "Public upload disabled by the administrator" : "Opinber innsending hefur verið gerð óvirk af kerfisstjóra.",
    "Public upload is only possible for publicly shared folders" : "Opinber innsending er einungis möguleg í möppur sem er deilt opinberlega",
    "Invalid date, date format must be YYYY-MM-DD" : "Ógild dagsetning, dagsetningasniðið verður að vera ÁÁÁÁ-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Deiling %s mistókst, því bakvinnslukerfið leyfir ekki sameignir af gerðinni %s",
    "Unknown share type" : "Óþekkt tegund sameignar",
    "Not a directory" : "Er ekki mappa",
    "Could not lock path" : "Gat ekki læst slóð",
    "Can't change permissions for public share links" : "Ekki tókst að breyta aðgangsheimildum fyrir opinbera deilingartengla",
    "Wrong or no update parameter given" : "Rangt eða ekkert uppfærsluviðfang gefið",
    "Cannot increase permissions" : "Get ekki aukið aðgangsheimildir",
    "A file or folder has been <strong>shared</strong>" : "Skjali eða  möppu hefur verið <strong>deilt</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Skjali eð  möppu hefur verið deilt <strong>frá öðrum þjóni</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Skrá eða mappa í almenningsaðgangi var <strong>sótt</strong>",
    "You received a new remote share %2$s from %1$s" : "Þú tókst við nýrri fjartengdri sameign %2$s frá %1$s",
    "You received a new remote share from %s" : "Þú tókst við nýrri fjartengdri sameign frá %s",
    "%1$s accepted remote share %2$s" : "%1$s samþykkti fjartengda sameign %2$s",
    "%1$s declined remote share %2$s" : "%1$s hafnaði fjartengdri sameign %2$s",
    "%1$s unshared %2$s from you" : "%1$s tók af deilingu %2$s frá þér",
    "Public shared folder %1$s was downloaded" : "Deild mappa í almenningsaðgangi %1$s var sótt",
    "Public shared file %1$s was downloaded" : "Deild skrá í almenningsaðgangi %1$s var sótt",
    "You shared %1$s with %2$s" : "Þú deildir %1$s með %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s deildi %1$s með %3$s",
    "You removed the share of %2$s for %1$s" : "Þú fjarlægðir deilingu af %2$s fyrir %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s fjarlægði deilingu af %3$s fyrir %1$s",
    "You shared %1$s with group %2$s" : "Þú deildir %1$s með hópnum %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s deildi %1$s með hópnum %3$s",
    "You removed the share of group %2$s for %1$s" : "Þú fjarlægðir deilingu til hópsins %2$s fyrir %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s fjarlægði deilingu til hópsins %3$s fyrir %1$s",
    "%2$s shared %1$s via link" : "%2$s deildi %1$s með tengli",
    "You shared %1$s via link" : "Þú deildir %1$s með tengli",
    "You removed the public link for %1$s" : "Þú fjarlægðir opinbera tengilinn fyrir %1$s",
    "%2$s removed the public link for %1$s" : "%2$s fjarlægði opinbera tengilinn fyrir %1$s",
    "Your public link for %1$s expired" : "Opinber tengill þinn fyrir %1$s er útrunninn",
    "The public link of %2$s for %1$s expired" : "Opinber tengill %2$s fyrir %1$s er útrunninn",
    "%2$s shared %1$s with you" : "%2$s deildi %1$s með þér",
    "%2$s removed the share for %1$s" : "%2$s fjarlægði deilingu af %1$s",
    "Downloaded via public link" : "Náð í með opinberum tengli",
    "Shared with %2$s" : "Deilt með %2$s",
    "Shared with %3$s by %2$s" : "Deilt með %3$s af %2$s",
    "Removed share for %2$s" : "Fjarlægði deilingu af %2$s",
    "%2$s removed share for %3$s" : "%2$s fjarlægði deilingu af %3$s",
    "Shared with group %2$s" : "Deilt með hópnum %2$s",
    "Shared with group %3$s by %2$s" : "Deilt með hópnum %3$s af %2$s",
    "Removed share of group %2$s" : "Fjarlægði deilingu af hópnum %2$s",
    "%2$s removed share of group %3$s" : "%2$s fjarlægði deilingu af hópnum %3$s",
    "Shared via link by %2$s" : "Deilt með tengli af %2$s",
    "Shared via public link" : "Deilt með opinberum tengli",
    "Removed public link" : "Fjarlægði opinberan tengil",
    "%2$s removed public link" : "%2$s fjarlægði opinberan tengil",
    "Public link expired" : "Opinber tengill er útrunninn",
    "Public link of %2$s expired" : "Opinber tengill %2$s er útrunninn",
    "Shared by %2$s" : "Deilt af %2$s",
    "Shares" : "Sameignir",
    "This share is password-protected" : "Þessi sameign er varin með lykilorði",
    "The password is wrong. Try again." : "Lykilorðið er rangt. Reyndu aftur.",
    "Password" : "Lykilorð",
    "No entries found in this folder" : "Engar skrár fundust í þessari möppu",
    "Name" : "Nafn",
    "Share time" : "Deilingartími",
    "Expiration date" : "Gildir til",
    "Sorry, this link doesn’t seem to work anymore." : "Því miður, þessi tengill virðist ekki virka lengur.",
    "Reasons might be:" : "Mögulegar ástæður gætu verið:",
    "the item was removed" : "atriðið var fjarlægt",
    "the link expired" : "tengillinn er útrunninn",
    "sharing is disabled" : "slökkt er á skráadeilingu",
    "For more info, please ask the person who sent this link." : "Til að vita meira skaltu hafa samband við þann sem sendi þér þennan tengil.",
    "%s is publicly shared" : "%s er deilt opinberlega",
    "Add to your ownCloud" : "Bæta í þitt eigið ownCloud",
    "Download" : "Niðurhal",
    "Download %s" : "Sækja %s",
    "Direct link" : "Beinn tengill"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
